==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/english/original_sections/admin/gui/admin_buttons.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_buttons.lang.inc.php 2017-09-05
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BUTTON_ACCOUNTING' => 'Admin Access',
	'BUTTON_ADD' => 'Add',
	'BUTTON_AFTERBUY_SEND' => 'Afterbuy: Send',
	'BUTTON_APPLY' => 'Apply',
	'BUTTON_ATTRIBUTES' => 'Attributes',
	'BUTTON_BACK' => 'Back',
	'BUTTON_BACKUP' => 'Backup',
	'BUTTON_BACKUP_IMAGES' => 'Backup Images',
	'BUTTON_CANCEL' => 'Cancel',
	'BUTTON_CLOSE' => 'Close',
	'BUTTON_CONFIRM' => 'Confirm',
	'BUTTON_COPY' => 'Copy',
	'BUTTON_COPY_LANGUAGE' => 'Copy Language',
	'BUTTON_CREATE' => 'Create',
	'BUTTON_CREATE_ACCOUNT' => 'New Customer',
	'BUTTON_DELETE' => 'Delete',
	'BUTTON_DETAILS' => 'Details',
	'BUTTON_DOWNLOAD' => 'Download',
	'BUTTON_EDIT' => 'Edit',
	'BUTTON_EDIT_ADDRESS' => 'Edit Address',
	'BUTTON_EDIT_ATTRIBUTES' => 'Edit Attributes',
	'BUTTON_EDIT_PRODUCTS' => 'Edit Products',
	'BUTTON_EDIT_TOTALS' => 'Edit Totals',
	'BUTTON_EMAIL' => 'Email',
	'BUTTON_EXPORT' => 'Export',
	'BUTTON_FILTER' => 'Filter',
	'BUTTON_IMPORT' => 'Import',
	'BUTTON_INSERT' => 'Insert',
	'BUTTON_INVOICE' => 'Invoice',
	'BUTTON_IPLOG' => 'IP Log',
	'BUTTON_MARK_AS_READ' => 'Mark as read',
	'BUTTON_LOAD_MORE_LOGS' => 'Load more logs',
	'BUTTON_LOAD_ALL_LOGS' => 'Load all logs',
	'BUTTON_MEDIAFINANZ_CREDITWORTHINESS' => 'Creditworthiness',
	'BUTTON_MODULE_INSTALL' => 'Install',
	'BUTTON_MODULE_REMOVE' => 'Uninstall',
	'BUTTON_MOVE' => 'Move',
	'BUTTON_NEW_BANNER' => 'New Banner',
	'BUTTON_NEW_CATEGORIES' => 'New Category',
	'BUTTON_NEW_CONTENT' => 'New Content',
	'BUTTON_NEW_COUNTRY' => 'New Country',
	'BUTTON_NEW_CURRENCY' => 'New Currency',
	'BUTTON_NEW_LANGUAGE' => 'Create Language',
	'BUTTON_NEW_NEWSLETTER' => 'New Newsletter',
	'BUTTON_NEW_ORDER' => 'New Order',
	'BUTTON_NEW_PREFIX' => 'New',
	'BUTTON_NEW_PREFIX_2' => 'New',
	'BUTTON_NEW_PRODUCTS' => 'New Product',
	'BUTTON_NEW_PRODUCTS_CONTENT' => 'New Products-Content',
	'BUTTON_NEW_TAX_CLASS' => 'New Tax Class',
	'BUTTON_NEW_TAX_RATE' => 'New Tax Rate',
	'BUTTON_NEW_ZONE' => 'New Zone',
	'BUTTON_OPEN' => 'Open',
	'BUTTON_ORDERS' => 'Orders',
	'BUTTON_PACKINGSLIP' => 'Packing Slip',
	'BUTTON_PREVIEW' => 'Preview',
	'BUTTON_PRODUCT_OPTIONS' => 'Product Attributes',
	'BUTTON_PROPERTIES' => 'Properties',
	'BUTTON_RELEASE' => 'Redeem',
	'BUTTON_REMOVE_CC_INFO' => 'Remove CC Info',
	'BUTTON_REPORT' => 'Report',
	'BUTTON_RESET' => 'Reset',
	'BUTTON_RESET_TO_DEFAULT_SETTINGS' => 'Reset to default settings',
	'BUTTON_RESTORE' => 'Restore',
	'BUTTON_REVERSE_SELECTION' => 'Reverse Selection',
	'BUTTON_REVIEW_APPROVE' => 'OK',
	'BUTTON_SAVE' => 'Save',
	'BUTTON_SEARCH' => 'Search',
	'BUTTON_SEND' => 'Send',
	'BUTTON_SEND_COUPON' => 'Send Coupon',
	'BUTTON_SEND_EMAIL' => 'Send Email',
	'BUTTON_SHOW' => 'Show',
	'BUTTON_SPECIAL' => 'Special Pricing',
	'BUTTON_START' => 'Start',
	'BUTTON_STATUS' => 'Customer Group',
	'BUTTON_STATUS_OFF' => 'Status Inactive',
	'BUTTON_STATUS_ON' => 'Status Active',
	'BUTTON_SWITCH_CATEGORIES' => 'Categories Only',
	'BUTTON_SWITCH_EDITOR_HTML' => 'HTML',
	'BUTTON_SWITCH_EDITOR_TEXT' => 'Text',
	'BUTTON_SWITCH_PRODUCTS' => 'Products Only',
	'BUTTON_UPDATE' => 'Update',
	'BUTTON_UPLOAD' => 'Upload',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/english/original_sections/admin/gui/admin_buttons.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	admin_buttons.lang.inc.php 2021-11-03
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2021 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'BUTTON_ACCOUNTING' => 'Admin Access',
	'BUTTON_ADD' => 'Add',
	'BUTTON_AFTERBUY_SEND' => 'Afterbuy: Send',
	'BUTTON_APPLY' => 'Apply',
	'BUTTON_BACK' => 'Back',
	'BUTTON_BACKUP' => 'Backup',
	'BUTTON_BACKUP_IMAGES' => 'Backup Images',
	'BUTTON_CANCEL' => 'Cancel',
	'BUTTON_CLOSE' => 'Close',
	'BUTTON_CONFIRM' => 'Confirm',
    'BUTTON_GO_TO_PRODUCT' => 'Open product',
	'BUTTON_COPY' => 'Copy',
	'BUTTON_COPY_LANGUAGE' => 'Copy Language',
	'BUTTON_CREATE' => 'Create',
	'BUTTON_CREATE_ACCOUNT' => 'New Customer',
	'BUTTON_DELETE' => 'Delete',
	'BUTTON_DETAILS' => 'Details',
	'BUTTON_DOWNLOAD' => 'Download',
	'BUTTON_EDIT' => 'Edit',
	'BUTTON_EDIT_ADDRESS' => 'Edit Address',
	'BUTTON_EDIT_PRODUCTS' => 'Edit Products',
	'BUTTON_EDIT_TOTALS' => 'Edit Totals',
	'BUTTON_EMAIL' => 'Email',
	'BUTTON_EXPORT' => 'Export',
	'BUTTON_FILTER' => 'Filter',
	'BUTTON_IMPORT' => 'Import',
	'BUTTON_INSERT' => 'Insert',
	'BUTTON_INVOICE' => 'Invoice',
	'BUTTON_IPLOG' => 'IP Log',
	'BUTTON_MARK_AS_READ' => 'Mark as read',
	'BUTTON_LOAD_MORE_LOGS' => 'Load more logs',
	'BUTTON_LOAD_ALL_LOGS' => 'Load all logs',
	'BUTTON_MEDIAFINANZ_CREDITWORTHINESS' => 'Creditworthiness',
	'BUTTON_MODULE_INSTALL' => 'Install',
	'BUTTON_MODULE_REMOVE' => 'Uninstall',
	'BUTTON_MOVE' => 'Move',
	'BUTTON_NEW_BANNER' => 'New Banner',
	'BUTTON_NEW_CATEGORIES' => 'New Category',
	'BUTTON_NEW_CONTENT' => 'New Content',
	'BUTTON_NEW_COUNTRY' => 'New Country',
	'BUTTON_NEW_CURRENCY' => 'New Currency',
	'BUTTON_NEW_LANGUAGE' => 'Create Language',
	'BUTTON_NEW_NEWSLETTER' => 'New Newsletter',
	'BUTTON_NEW_ORDER' => 'New Order',
	'BUTTON_NEW_PREFIX' => 'New',
	'BUTTON_NEW_PREFIX_2' => 'New',
	'BUTTON_NEW_PRODUCTS' => 'New Product',
	'BUTTON_NEW_PRODUCTS_CONTENT' => 'New Products-Content',
	'BUTTON_NEW_TAX_CLASS' => 'New Tax Class',
	'BUTTON_NEW_TAX_RATE' => 'New Tax Rate',
	'BUTTON_NEW_ZONE' => 'New Zone',
	'BUTTON_OPEN' => 'Open',
	'BUTTON_ORDERS' => 'Orders',
	'BUTTON_PACKINGSLIP' => 'Packing Slip',
	'BUTTON_PREVIEW' => 'Preview',
	'BUTTON_PRODUCT_OPTIONS' => 'Add. Options',
	'BUTTON_PROPERTIES' => 'Variants',
	'BUTTON_RELEASE' => 'Redeem',
	'BUTTON_REMOVE_CC_INFO' => 'Remove CC Info',
	'BUTTON_REPORT' => 'Report',
	'BUTTON_RESET' => 'Reset',
	'BUTTON_RESET_TO_DEFAULT_SETTINGS' => 'Reset to default settings',
	'BUTTON_RESTORE' => 'Restore',
	'BUTTON_REVERSE_SELECTION' => 'Reverse Selection',
	'BUTTON_REVIEW_APPROVE' => 'OK',
	'BUTTON_SAVE' => 'Save',
	'BUTTON_SEARCH' => 'Search',
	'BUTTON_SEND' => 'Send',
	'BUTTON_SEND_COUPON' => 'Send Coupon',
	'BUTTON_SEND_EMAIL' => 'Send Email',
	'BUTTON_SHOW' => 'Show',
	'BUTTON_SPECIAL' => 'Special',
	'BUTTON_START' => 'Start',
	'BUTTON_STATUS' => 'Customer Group',
	'BUTTON_STATUS_OFF' => 'Status Inactive',
	'BUTTON_STATUS_ON' => 'Status Active',
	'BUTTON_SWITCH_CATEGORIES' => 'Categories Only',
	'BUTTON_SWITCH_EDITOR_HTML' => 'HTML',
	'BUTTON_SWITCH_EDITOR_TEXT' => 'Text',
	'BUTTON_SWITCH_PRODUCTS' => 'Products Only',
	'BUTTON_UPDATE' => 'Update',
	'BUTTON_UPLOAD' => 'Upload',
	'BUTTON_PRODUCT_DOWNLOADS' => 'Downloads',
);
